==> ec2init-0.11-py3-none-any.whl: ec2init/utils/dns.py <==
import logging
import time

import dns.resolver
from typing import Optional

from .system import SystemUtils

logger = logging.getLogger(__name__)

class DnsUtils:

    @staticmethod
    def get_ip_from_name(domain_name: str, max_attempts: int = 60, sleep_attempts_sec: int = 1) -> Optional[str]:
        attempts = 1
        while (attempts < max_attempts):
            try:
                answer = dns.resolver.query(domain_name, 'A')
                ip = DnsUtils._get_ip(answer)
                logger.info("Domain name %s resolves to %s", domain_name, ip)
                return ip
            except (dns.resolver.NXDOMAIN, dns.resolver.NoNameservers) as ex:
                logger.warning("Could not resolve domain name %s", domain_name)
                attempts += 1
                if attempts >= max_attempts:
                    raise ex
                
                if float(attempts/5).is_integer():
                    DnsUtils._flush_cache()
                time.sleep(sleep_attempts_sec)
        return None

    @staticmethod
    def _get_ip(dns_response: dns.resolver.Answer) -> str:
        ips = [a.address for a in dns_response]
        return ips[0]

    @staticmethod
    def _flush_cache() -> None:
        try:
            logger.info("Flushing DNS cache")
            resolver_cache = dns.resolver.get_default_resolver().cache
            if resolver_cache is not None:
                resolver_cache.flush()
            
            SystemUtils.execute_command("systemd-resolve --flush-caches".split(" "), check=False)
            SystemUtils.execute_command("systemctl restart dnsmasq".split(" "), check=False)
        except Exception as ex:
            logger.warn("Could not flush DNS cache: %s", ex)

==> ec2init-0.19.1-py3-none-any.whl: ec2init/utils/dns.py <==
import logging
import time

import dns.resolver
from typing import Optional

from .system import SystemUtils

logger = logging.getLogger(__name__)

class DnsUtils:

    @staticmethod
    def get_ip_from_name(domain_name: str, max_attempts: int = 60, sleep_attempts_sec: int = 1) -> Optional[str]:
        attempts = 1
        while (attempts < max_attempts):
            try:
                answer = dns.resolver.query(domain_name, 'A')
                ip = DnsUtils._get_ip(answer)
                logger.info("Domain name %s resolves to %s", domain_name, ip)
                return ip
            except (dns.resolver.NXDOMAIN, dns.resolver.NoNameservers) as ex:
                logger.warning("Could not resolve domain name %s", domain_name)
                attempts += 1
                if attempts >= max_attempts:
                    raise ex
                
                if float(attempts/5).is_integer():
                    DnsUtils._flush_cache()
                time.sleep(sleep_attempts_sec)
        return None

    @staticmethod
    def _get_ip(dns_response: dns.resolver.Answer) -> str:
        ips = [a.address for a in dns_response]
        return ips[0]

    @staticmethod
    def _flush_cache() -> None:
        try:
            logger.info("Flushing DNS cache")
            resolver_cache = dns.resolver.get_default_resolver().cache
            if resolver_cache is not None:
                resolver_cache.flush()
            
            try:
                SystemUtils.execute_command("resolvectl flush-caches".split(" "), check=False)
            except Exception:
                logger.warn("Failed to flush systemd-resolved DNS cache, running CentOS?")
            SystemUtils.execute_command("systemctl restart dnsmasq".split(" "), check=False)
        except Exception as ex:
            logger.warn("Could not flush DNS cache: %s", ex)
